===============================
FURY
===============================

.. image:: https://img.shields.io/travis/fury-gl/fury.svg
        :target: https://travis-ci.org/fury-gl/fury

.. image:: https://img.shields.io/pypi/v/fury.svg
        :target: https://pypi.python.org/pypi/fury

.. image:: https://codecov.io/gh/fury-gl/fury/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/fury-gl/fury


Free Unified Rendering in Python

* Free software: 3-clause BSD license
* Documentation: https://fury.gl

Features
--------

* TODO
